package at.xaxa.ledger.ui.home

import android.annotation.SuppressLint
import androidx.compose.foundation.ExperimentalFoundationApi
import androidx.compose.foundation.layout.Box
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.layout.width
import androidx.compose.foundation.lazy.LazyColumn
import androidx.compose.foundation.lazy.items
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.runtime.collectAsState
import androidx.compose.runtime.getValue
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import androidx.lifecycle.viewmodel.compose.viewModel
import at.xaxa.ledger.ui.AppViewModelProvider
import at.xaxa.ledger.ui.ButtonSuccess
import at.xaxa.ledger.ui.HeaderCard
import at.xaxa.ledger.ui.HorizontalCard
import at.xaxa.ledger.ui.convertMillisToDate

@SuppressLint("DefaultLocale")
@OptIn(ExperimentalFoundationApi::class)
@Composable
fun Home(modifier: Modifier = Modifier, onCardClick: (Int) -> Unit, onButtonClick: () -> Unit, onCatButtonClick: () -> Unit, homeViewModel : HomeViewModel = viewModel(factory = AppViewModelProvider.Factory)) {
    val state by homeViewModel.entryUIState.entry.collectAsState(initial = emptyList())
    homeViewModel.calculateBalance()
    val balance = homeViewModel.balance

    Column(
        modifier = Modifier
            .fillMaxSize()
            .padding(16.dp, 0.dp),
        horizontalAlignment = Alignment.CenterHorizontally
    ) {

        LazyColumn(
            modifier = Modifier
                .weight(1f)
        ) {

            stickyHeader {
                HeaderCard(modifier = modifier, "%.2f".format(balance)+"€", onCatButtonClick)

                Text(
                    text = "Your Transactions",
                    fontSize = 24.sp,
                    fontWeight = FontWeight.Bold,
                    modifier = Modifier
                        .padding(vertical = 16.dp)
                        .align(Alignment.Start)
                )
            }

            items(state) { item ->
                Column(
                    modifier = Modifier.padding(vertical = 4.dp)
                ) {


                    HorizontalCard(
                        modifier = modifier,
                        name = item.name,
                        date = convertMillisToDate(item.date),
                        amount = "%.2f".format(item.amount)+"€",
                        iconId = item.icon,
                        onClick = { onCardClick(item.entryId) }
                    )
                }
            }
        }

        // Sticky footer content
        Box(
            modifier = Modifier
                .fillMaxWidth(),
            contentAlignment = Alignment.Center
        ) {
            ButtonSuccess(modifier = Modifier, "Add Transaction", onClick = { onButtonClick() })
        }
    }
}

